summaryrefslogtreecommitdiff
path: root/src/mongo/s/catalog/sharding_catalog_client.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/s/catalog/sharding_catalog_client.h')
-rw-r--r--src/mongo/s/catalog/sharding_catalog_client.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/src/mongo/s/catalog/sharding_catalog_client.h b/src/mongo/s/catalog/sharding_catalog_client.h
index 1d736fb222d..f334c05a477 100644
--- a/src/mongo/s/catalog/sharding_catalog_client.h
+++ b/src/mongo/s/catalog/sharding_catalog_client.h
@@ -429,10 +429,12 @@ public:
const WriteConcernOptions& writeConcern) = 0;
/**
* Appends the information about the config and admin databases in the config server
* with the format for listDatabase.
*/
virtual Status appendInfoForConfigServerDatabases(OperationContext* txn,
+ const BSONObj& listDatabasesCmd,
BSONArrayBuilder* builder) = 0;
/**
@@ -429,10 +429,12 @@ public:
const WriteConcernOptions& writeConcern) = 0;
/**
- * Appends the information about the config and admin databases in the config server
- * with the format for listDatabase.
+ * Appends the information about the config and admin databases in the config server with the
+ * format for listDatabases, based on the listDatabases command parameters in
+ * 'listDatabasesCmd'.
*/
virtual Status appendInfoForConfigServerDatabases(OperationContext* txn,